@@ -57,6 +57,7 @@ class QuickbooksOnlineSDK:
         self.journal_entries = JournalEntries()
         self.attachments = Attachments()
         self.bill_payments = BillPayments()
+        self.tax_codes = TaxCodes()
 
         self.update_server_url()
         self.update_access_token()
@@ -81,6 +82,7 @@ class QuickbooksOnlineSDK:
         self.customers.set_server_url(base_url)
         self.attachments.set_server_url(base_url)
         self.bill_payments.set_server_url(base_url)
+        self.tax_codes.set_server_url(base_url)
 
     def update_access_token(self):
         """
@@ -103,6 +105,7 @@ class QuickbooksOnlineSDK:
         self.customers.change_access_token(access_token)
         self.attachments.change_access_token(access_token)
         self.bill_payments.change_access_token(access_token)
+        self.tax_codes.change_access_token(access_token)
 
     def __get_access_token(self):
         """Get the access token using a HTTP post.
